ClusterClonotypes: Find relationships between clonotypes

View source: R/mito.R

ClusterClonotypesR Documentation

Find relationships between clonotypes

Description

Perform hierarchical clustering on clonotype data

Usage

ClusterClonotypes(object, assay = NULL, group.by = NULL)

Arguments

object

A Seurat object

assay

Name of assay to use

group.by

Grouping variable for cells

Value

Returns a list containing two objects of class stats::hclust(), one for the cell clustering and one for the feature (allele) clustering


Signac documentation built on April 1, 2026, 5:06 p.m.