DepthCor: Plot sequencing depth correlation

View source: R/visualization.R

DepthCorR Documentation

Plot sequencing depth correlation

Description

Compute the correlation between total counts and each reduced dimension component.

Usage

DepthCor(object, assay = NULL, reduction = "lsi", n = 10, ...)

Arguments

object

A SeuratObject::Seurat() object

assay

Name of assay to use for sequencing depth. If NULL, use the default assay.

reduction

Name of a dimension reduction stored in the input object

n

Number of components to use. If NULL, use all components.

...

Additional arguments passed to stats::cor()

Value

Returns a ggplot2::ggplot() object

Examples


DepthCor(object = atac_small)


Signac documentation built on April 1, 2026, 5:06 p.m.