| EnrichedTerms | R Documentation |
Run ontology term enrichment testing on differential features for each of the
identity classes. Runs fgsea::fgsea() on differential testing
results from each identity class.
EnrichedTerms(
object,
terms,
group.by = NULL,
assay = NULL,
var.features = TRUE,
scoreType = "std",
top.n = NULL,
verbose = TRUE,
...
)
object |
A Seurat object. |
terms |
Ontology term list. The name of each element in the list should be an ontology term, and the list elements a vector of feature names present in the assay. |
group.by |
Name of grouping variable to use. If NULL, use the active cell identities. |
assay |
Name of assay to use. If NULL, use the default assay. |
var.features |
Subset to only variable features for ontology term enrichment. |
scoreType |
|
top.n |
Number of top enriched terms to retain for each set of cells. If NULL, retain all terms. |
verbose |
Display messages. |
... |
Additional arguments passed to |
Returns a named list of dataframes. Each element of the list contains a dataframe with the term enrichment results for an identity class.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.