GRangesToString: GRanges to String

View source: R/utilities.R

GRangesToStringR Documentation

GRanges to String

Description

[Deprecated]

Usage

GRangesToString(grange, sep = c("-", "-"))

Arguments

grange

A GRanges object

sep

Vector of separators to use for genomic string. First element is used to separate chromosome and coordinates, second separator is used to separate start and end coordinates.

Details

Convert GRanges object to a vector of strings

Value

Returns a character vector

Examples

GRangesToString(grange = blacklist_hg19)

Signac documentation built on April 1, 2026, 5:06 p.m.