TSSPlot: Plot signal enrichment around TSSs

View source: R/visualization.R

TSSPlotR Documentation

Plot signal enrichment around TSSs

Description

[Deprecated]

Usage

TSSPlot(object, assay = NULL, group.by = NULL, idents = NULL)

Arguments

object

A Seurat object

assay

Name of the assay to use. Should have the TSS enrichment information for each cell already computed by running TSSEnrichment()

group.by

Set of identities to group cells by

idents

Set of identities to include in the plot

Details

Plot the normalized TSS enrichment score at each position relative to the TSS. Requires that TSSEnrichment() has already been run on the assay.

Value

Returns a ggplot2::ggplot2() object


Signac documentation built on April 1, 2026, 5:06 p.m.